[PATCH atubs-fw 2/4] atusb/fw: Use RX_AACK_ON instead of RX_ON in the firmware.

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



This allows to run the device in ARET networks as we handle the needed
automated ACK in hardware.

Signed-off-by: Stefan Schmidt <stefan@xxxxxxxxxxxxxxxxxx>
---
 atusb/fw/mac.c | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/atusb/fw/mac.c b/atusb/fw/mac.c
index 2344b99..08ed00a 100644
--- a/atusb/fw/mac.c
+++ b/atusb/fw/mac.c
@@ -182,7 +182,7 @@ bool mac_rx(int on)
 	if (on) {
 		mac_irq = handle_irq;
 		reg_read(REG_IRQ_STATUS);
-		change_state(TRX_CMD_RX_ON);
+		change_state(TRX_CMD_RX_AACK_ON);
 	} else {
 		mac_irq = NULL;
 		change_state(TRX_CMD_FORCE_TRX_OFF);
@@ -232,9 +232,9 @@ static void do_tx(void *user)
 
 	/*
 	 * Wait until we reach BUSY_TX, so that we command the transition to
 	 * RX_ON which will be executed upon TX completion.
 	 */
-	change_state(TRX_CMD_RX_ON);
+	change_state(TRX_CMD_RX_AACK_ON);
 }
 
 
@@ -232,9 +232,9 @@ static void do_tx(void *user)
 	/*
 	 * Wait until we reach BUSY_TX, so that we command the transition to
-	 * RX_ON which will be executed upon TX completion.
+	 * RX_AACK_ON which will be executed upon TX completion.
 	 */
-- 
2.1.0

--
To unsubscribe from this list: send the line "unsubscribe linux-wpan" in
the body of a message to majordomo@xxxxxxxxxxxxxxx
More majordomo info at  http://vger.kernel.org/majordomo-info.html




[Index of Archives]     [Linux NFS]     [Linux NILFS]     [Linux USB Devel]     [Linux Audio Users]     [Photo]     [Yosemite News]     [Linux Kernel]     [Linux SCSI]

  Powered by Linux